<img src="https://github.com/blackcater/blackcater/raw/main/images/Hi.gif" height="32"/></h1>
<a href="https://git.io/typing-svg"><img src="https://readme-typing-svg.demolab.com?font=Fira+Code&pause=1000&width=600&height=60&lines=Hi+there%2C+I'm+your+personal+assistant+Ostap" alt="Typing SVG" /></a>

<img src="https://img.shields.io/badge/made%20by-GoIT Team 3-blue.svg" >

Description in other languages:         
        <a href="https://github.com/NeverInMind/Project_Team3/blob/dev/README.ua.md">
        <img src="https://em-content.zobj.net/thumbs/120/apple/354/flag-ukraine_1f1fa-1f1e6.png" alt="UA" width="40" height="40"></a>
        <a href="https://github.com/NeverInMind/Project_Team3/blob/dev/README.md">
        <img src="https://em-content.zobj.net/thumbs/120/apple/354/flag-united-states_1f1fa-1f1f8.png" alt="EN" width="40" height="40"></a>

## How to install me
* Just write down in your console: ``pip install assistant-ostap==0.0.2``

P.S. don't forget that I need installed Python on your computer :wink:

## How to start me 
* Just call me in your console by command ``Ostap``



## What I can do
* Create a contact book for you by command ``add``
* Tell us who has a birthday in the coming N days ``show nearbday N`` (N - numbers of days)
* Create notes for you
* And many intresting things

### You can find out the full list of my capabilities by installing me and entering the command ``help``

